phonenumbertypes

package
v1.0.70 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 6, 2017 License: MIT Imports: 1 Imported by: 0

Documentation

Overview

Phone number types allow you to attach a type to different phone numbers.

Help Center

Full documentation can be found in the Ticketmatic Help Center (https://www.ticketmatic.com/docs/api/settings/system/phonenumbertypes).

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Create

Create a new phone number type

func Delete

func Delete(client *ticketmatic.Client, id int64) error

Remove a phone number type

Phone number types are archivable: this call won't actually delete the object from the database. Instead, it will mark the object as archived, which means it won't show up anymore in most places.

Most object types are archivable and can't be deleted: this is needed to ensure consistency of historical data.

func Get

Get a single phone number type

func Translate

func Translate(client *ticketmatic.Client, id int64, data map[string]string) (map[string]string, error)

Update translations

Sets updated translation strings.

See translations (https://www.ticketmatic.com/docs/api/coreconcepts/translations) for more information.

func Translations

func Translations(client *ticketmatic.Client, id int64) (map[string]string, error)

Fetch translatable fields

Returns a dictionary with string values in all languages for each translatable field.

See translations (https://www.ticketmatic.com/docs/api/coreconcepts/translations) for more information.

func Update

Modify an existing phone number type

Types

type List

type List struct {
	// Result data
	Data []*ticketmatic.PhoneNumberType `json:"data"`

	// The total number of results that are available without considering limit and offset, useful for paging.
	NbrOfResults int `json:"nbrofresults"`
}

List results

func Getlist

func Getlist(client *ticketmatic.Client, params *ticketmatic.PhoneNumberTypeQuery) (*List, error)

Get a list of phone number types

Jump to