Documentation
¶
Overview ¶
Phone number types allow you to attach a type to different phone numbers.
Help Center ¶
Full documentation can be found in the Ticketmatic Help Center (https://www.ticketmatic.com/docs/api/settings/system/phonenumbertypes).
Index ¶
- func Create(client *ticketmatic.Client, data *ticketmatic.PhoneNumberType) (*ticketmatic.PhoneNumberType, error)
- func Delete(client *ticketmatic.Client, id int64) error
- func Get(client *ticketmatic.Client, id int64) (*ticketmatic.PhoneNumberType, error)
- func Translate(client *ticketmatic.Client, id int64, data map[string]string) (map[string]string, error)
- func Translations(client *ticketmatic.Client, id int64) (map[string]string, error)
- func Update(client *ticketmatic.Client, id int64, data *ticketmatic.PhoneNumberType) (*ticketmatic.PhoneNumberType, error)
- type List
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Create ¶
func Create(client *ticketmatic.Client, data *ticketmatic.PhoneNumberType) (*ticketmatic.PhoneNumberType, error)
Create a new phone number type
func Delete ¶
func Delete(client *ticketmatic.Client, id int64) error
Remove a phone number type
Phone number types are archivable: this call won't actually delete the object from the database. Instead, it will mark the object as archived, which means it won't show up anymore in most places.
Most object types are archivable and can't be deleted: this is needed to ensure consistency of historical data.
func Get ¶
func Get(client *ticketmatic.Client, id int64) (*ticketmatic.PhoneNumberType, error)
Get a single phone number type
func Translate ¶
func Translate(client *ticketmatic.Client, id int64, data map[string]string) (map[string]string, error)
Update translations
Sets updated translation strings.
See translations (https://www.ticketmatic.com/docs/api/coreconcepts/translations) for more information.
func Translations ¶
Fetch translatable fields
Returns a dictionary with string values in all languages for each translatable field.
See translations (https://www.ticketmatic.com/docs/api/coreconcepts/translations) for more information.
func Update ¶
func Update(client *ticketmatic.Client, id int64, data *ticketmatic.PhoneNumberType) (*ticketmatic.PhoneNumberType, error)
Modify an existing phone number type
Types ¶
type List ¶
type List struct {
// Result data
Data []*ticketmatic.PhoneNumberType `json:"data"`
// The total number of results that are available without considering limit and offset, useful for paging.
NbrOfResults int `json:"nbrofresults"`
}
List results
func Getlist ¶
func Getlist(client *ticketmatic.Client, params *ticketmatic.PhoneNumberTypeQuery) (*List, error)
Get a list of phone number types